/**
 * 深拷贝
 * @param {any} target 要拷贝的对象
 * @param {map对象} map 解决循环引用问题，默认传空
 */
function cloneDeep(target, map = new WeakMap()) {
	if (typeof target == 'object' && target != null) {
		let isArray = Array.isArray(target);
		let cloneTarget = isArray ? [] : {};
		// 解决循环依赖
		if (map.get(target)) {
			return map.get(target);
		}
		map.set(target, cloneTarget);
		for (let key in target) {
			cloneTarget[key] = cloneDeep(target[key], map);
		}
		return cloneTarget;
	} else {
		return target;
	}
}

export default cloneDeep;
