/**
 * 节流函数
 * @param {Function} fn 延迟执行函数
 * @param {*} wait 延迟函数执行时间间隔
 * @param {*} immd 第一次调用是否立即执行
 */
function throttle(fn, wait, immd) {
	let lastTime = 0;
	return function() {
		let now = Date.now();

		// 不是立即执行的话，将上一次时间设置为现在时间则不执行
		if (!immd && !lastTime) {
			lastTime = now;
		}
		if (now - lastTime >= wait) {
			lastTime = now;
			return fn.apply(this, arguments);
		}
	};
}
export default throttle;
